@@ -11,15 +11,16 @@ import locale
 from datetime import datetime
 from binaryornot.check import is_binary
 import fosslight_util.constant as constant
-from fosslight_util.set_log import init_log, init_log_item
+from fosslight_util.set_log import init_log
 from yaml import safe_dump
 from reuse import report
 from reuse.project import Project
 from reuse.report import ProjectReport
 
 _PKG_NAME = "fosslight_reuse"
-_MSG_REFERENCE = "Ref. Copyright and License Writing Rules in Source Code. : http://collab.lge.com/main/x/1eb-LQ"
-_MSG_FOLLOW_LIC_TXT = "Follow the Copyright and License Writing Rules in Source Code. : http://collab.lge.com/main/x/1eb-LQ"
+_RULE_LINK = "https://oss.lge.com/guide/process/osc_process/1-identification/copyright_license_rule.html"
+_MSG_REFERENCE = "Ref. Copyright and License Writing Rules in Source Code. : " + _RULE_LINK
+_MSG_FOLLOW_LIC_TXT = "Follow the Copyright and License Writing Rules in Source Code. : " + _RULE_LINK
 _REUSE_CONFIG_FILE = ".reuse/dep5"
 _DEFAULT_EXCLUDE_EXTENSION_FILES = []  # Exclude files from reuse
 _DEFAULT_EXCLUDE_EXTENSION = ["jar", "png", "exe", "so", "a", "dll", "jpeg", "jpg", "ttf", "lib", "ttc", "pfb",
@@ -293,8 +294,8 @@ def init(path_to_find, result_file, file_list):
 
     _start_time = datetime.now().strftime('%Y%m%d_%H-%M-%S')
     output_dir = os.path.dirname(os.path.abspath(result_file))
-    logger = init_log(os.path.join(output_dir, "fosslight_reuse_log_"+_start_time+".txt"))
-    _result_log = init_log_item(_PKG_NAME, path_to_find)
+    logger, _result_log = init_log(os.path.join(output_dir, "fosslight_reuse_log_"+_start_time+".txt"),
+                                   True, logging.INFO, logging.DEBUG, _PKG_NAME, path_to_find)
     if file_list:
         _result_log["File list to check"] = file_list
 
